@@ -73,6 +73,7 @@ def train_from_folder(
     new = False,
     load_from = -1,
     image_size = 256,
+    optimizer="adam",
     fmap_max = 512,
     transparent = False,
     batch_size = 10,
@@ -105,6 +106,7 @@ def train_from_folder(
         hamburger_res_layers = cast_list(hamburger_res_layers),
         disc_output_size = disc_output_size,
         image_size = image_size,
+        optimizer = optimizer,
         fmap_max = fmap_max,
         transparent = transparent,
         lr = learning_rate,
